Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DictionaryOverflowEvent ¶
type DictionaryOverflowEvent struct {
FieldName string
PrevIndexType arrow.DataType
NewIndexType arrow.DataType
Cardinality uint64
Total uint64
}
DictionaryOverflowEvent is an event that is triggered when a dictionary overflows its index type.
func (*DictionaryOverflowEvent) Notify ¶
func (e *DictionaryOverflowEvent) Notify(recordName string, observer observer.ProducerObserver)
type DictionaryResetEvent ¶
type DictionaryResetEvent struct {
FieldName string
IndexType arrow.DataType
Cardinality uint64
Total uint64
}
DictionaryResetEvent is an event that is triggered when a dictionary is reset instead of being overflowed. This happens when dictionary entries are reused in average more than a specific threshold.
func (*DictionaryResetEvent) Notify ¶
func (e *DictionaryResetEvent) Notify(recordName string, observer observer.ProducerObserver)
type DictionaryUpgradeEvent ¶
type DictionaryUpgradeEvent struct {
FieldName string
PrevIndexType arrow.DataType
NewIndexType arrow.DataType
Cardinality uint64
Total uint64
}
DictionaryUpgradeEvent is an event that is triggered when a dictionary is upgraded to a larger index type.
func (*DictionaryUpgradeEvent) Notify ¶
func (e *DictionaryUpgradeEvent) Notify(recordName string, observer observer.ProducerObserver)
type FieldUpdateEvent ¶
type FieldUpdateEvent interface {
// Notify notifies the observer of a specific field update event.
Notify(recordName string, observer observer.ProducerObserver)
}
FieldUpdateEvent is an interface for all field update events.
type MetadataEvent ¶
type MetadataEvent struct {
MetadataKey string
}
MetadataEvent is an event that is triggered when schema metadata are updated.
func (*MetadataEvent) Notify ¶
func (e *MetadataEvent) Notify(recordName string, observer observer.ProducerObserver)
type NewFieldEvent ¶
type NewFieldEvent struct {
FieldName string
}
NewFieldEvent is an event that is triggered when a new field is added to a schema.
func (*NewFieldEvent) Notify ¶
func (e *NewFieldEvent) Notify(recordName string, observer observer.ProducerObserver)
type SchemaUpdateRequest ¶
type SchemaUpdateRequest struct {
// contains filtered or unexported fields
}
SchemaUpdateRequest is a counter that keeps track of the number of schema update requests.
func NewSchemaUpdateRequest ¶
func NewSchemaUpdateRequest() *SchemaUpdateRequest
NewSchemaUpdateRequest creates a new SchemaUpdateRequest.
func (*SchemaUpdateRequest) Count ¶
func (r *SchemaUpdateRequest) Count() int
Count returns the current count of the schema update request.
func (*SchemaUpdateRequest) Inc ¶
func (r *SchemaUpdateRequest) Inc(event FieldUpdateEvent)
Inc increments the counter of the schema update request by one.
func (*SchemaUpdateRequest) Notify ¶
func (r *SchemaUpdateRequest) Notify(recordName string, observer observer.ProducerObserver)
Notify notifies the observer passed as argument of all events that have occurred since the last call to Notify.
func (*SchemaUpdateRequest) Reset ¶
func (r *SchemaUpdateRequest) Reset()
Reset resets the counter of the schema update request to zero.